@@ -7,7 +7,11 @@ class RecurringFibNumberTest(TestCase):
         self.assertEqual(0, recurring_fibonacci_number(number=0))
 
     def test_negative(self):
-        self.assertEqual(None, recurring_fibonacci_number(number=-1))
+        with self.assertRaises(ValueError) as raised_error:
+            recurring_fibonacci_number(number=-1)
+        self.assertEqual(
+            "Fibonacci has to be equal or above zero", str(raised_error.exception)
+        )
 
     def test_one(self):
         self.assertEqual(1, recurring_fibonacci_number(number=1))
@@ -18,5 +22,6 @@ class RecurringFibNumberTest(TestCase):
     def test_twenty(self):
         self.assertEqual(6765, recurring_fibonacci_number(number=20))
 
+
 if __name__ == "__main__":
     main()
